"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const generator_1 = require("./generator");
const parser_1 = require("./parser");
const tokenizer_1 = require("./tokenizer");
/**
 * The compiler takes a swift pattern string and returns a swift object.
 *
 * ```
 * compiler("35a");
 *      {
 *          linesCount: 1,
 *          lines: [
 *              {
 *                  minChars: 0,
 *                  maxChars: 35,
 *                  regExp: /[A-Z]{0,35}/,
 *                  allowedCharsClass: /[A-Z]/,
 *              },
 *          ],
 *          maxChars: 35,
 *          regExp: /[A-Z]{0,35}/,
 *          allowedCharsClass: /[A-Z]/,
 *      }
 * ```
 * @param input the swift pattern for compilation
 */
exports.compiler = (input) => {
    const tokens = tokenizer_1.tokenizer(input);
    const ast = parser_1.parser(tokens);
    const output = generator_1.generator(ast);
    return output;
};
exports.default = exports.compiler;
//# sourceMappingURL=compiler.js.map